@@ -8,7 +8,7 @@ function (list, fits, refName = "Ref", ...)
         warning("Possible mismatch in 'fits2simFits'")
     result <- NULL
     for (i in 1:n) result <- append(result, list(sub2simFits(list[[i]], 
-        fit = fits[[i]], ...)))
+        fit = fits[[i]], refName = refName, ...)))
     names(result) <- names(list)
     result
 }
